//
// MoonCanvas.h
// Draw the moon and related info.
//
//    Copyright 2002 by Akkana Peck.
// You may use or distribute this code under the terms of the GPL.
//

#ifndef MOONCANVAS_H
#define MOONCANVAS_H

#include "qwidget.h"

#include <qstring.h>

#include <sys/time.h>

class QImage;
class MoonFeature;
class QPainter;

class MoonCanvas : public QWidget
{
    Q_OBJECT
public:
    MoonCanvas( QWidget *parent=0, const char *name=0 );
    virtual ~MoonCanvas();

    void Init();

    void ToggleMirrored();
    void Zoom(int level);

    void Clear();
    virtual void Paint();

    static void SetDebugMode(int yes) { sDebugMode = yes; };

public slots:

signals:

protected:
    int mMoonRadius;
    int mMoonCenterX, mMoonCenterY;
    QImage* mMoonImg;
    int mMirrored;
    int mZoomLevel;
    int mMinLong, mMaxLong;
    int mMinLat, mMaxLat;

    QPainter* mPainter;

    int mCraterNum;
#define MAX_OBJECTS_SHOWN 6
    MoonFeature* mMatches[MAX_OBJECTS_SHOWN];

    // All images have some inherent libration, alas.  Compensate:
    int mImgLibrationE;
    int mImgLibrationN;

    // Save description strings in case we get a chance to show them
    QString mDescriptions;

    // Time of last mouse button down event:
    struct timeval mLastButtonDownTime;

    static int sDebugMode;

    // Override QWidget:
    virtual void paintEvent(QPaintEvent* event);

    void PaintFeature(MoonFeature* feature);
    void mousePressEvent(QMouseEvent *event);
    void mouseReleaseEvent(QMouseEvent *event);

    //QSize minimumSizeHint() const;
};

#endif // MOONCANVAS_H
